{theme=documentation}

\include{"../include.md"}

\title{"Getting Started" "Basic Usage"}


## Install Themes

Before we can start to use luke we should install some themes.

**List Available Themes**
```
luke --list
```

**Install Themes**
We recommend to install these Themes first.
```
luke --install bootstrap
luke --install bootstrap_cdn
luke --install vctheme
luke --install vctheme_cdn
luke --install documentation
```

## Parse the Docs yourself
```
luke --doc
```

## ... or run the live-server anywhere
```
luke --live
```
